=======
History
=======

0.1.2 (2022-01-13)
------------------

* First release on PyPI.


0.2.1 (2022-01-18)
------------------

* Self-contained celery task and worker app
* Subclassing ORSimAgent and adding to an instance of ORSimScheduler will automatically distribute agents among the various celery instances



